@@ -1,7 +1,7 @@
 /*
- * Copyright (C) 2015 Richard Hughes <richard@hughsie.com>
+ * Copyright 2015 Richard Hughes <richard@hughsie.com>
  *
- * SPDX-License-Identifier: LGPL-2.1+
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 /**
  * SECTION:xb-version
@@ -11,12 +11,9 @@
  * depending on the version of libxmlb installed.
  */
 
-#if !defined (__LIBXMLB_H_INSIDE__) && !defined (LIBXMLB_COMPILATION)
-#error "Only <libxmlb.h> can be included directly."
-#endif
+#pragma once
 
-#ifndef __LIBXMLB_VERSION_H
-#define __LIBXMLB_VERSION_H
+#include <glib.h>
 
 /**
  * XMLB_MAJOR_VERSION:
@@ -42,7 +39,7 @@
  * The compile-time micro version
  */
 #ifndef XMLB_MICRO_VERSION
-#define XMLB_MICRO_VERSION				(10)
+#define XMLB_MICRO_VERSION				(25)
 #endif
 
 /**
@@ -60,4 +57,8 @@
      (XMLB_MAJOR_VERSION == (major) && XMLB_MINOR_VERSION == (minor) && \
       XMLB_MICRO_VERSION >= (micro)))
 
-#endif /* __LIBXMLB_VERSION_H */
+G_BEGIN_DECLS
+
+const gchar	*xb_version_string	(void);
+
+G_END_DECLS
